@@ -158,6 +158,7 @@ public class Browser {
 	[Glade.Widget] CheckMenuItem showinheritedmembers;
 	[Glade.Widget] CheckMenuItem comments1;
 	[Glade.Widget] MenuItem postcomment;
+	[Glade.Widget] public MenuItem cut1;
 	[Glade.Widget] public MenuItem paste1;
 	[Glade.Widget] public MenuItem print;
 	public Notebook tabs_nb;
@@ -243,9 +244,9 @@ public class Browser {
                 
 		Stream icon = GetResourceImage ("monodoc.png");
 
-                if (icon != null){
+		if (icon != null) {
 			monodoc_pixbuf = new Gdk.Pixbuf (icon);
-                        MainWindow.Icon = monodoc_pixbuf;
+			MainWindow.Icon = monodoc_pixbuf;
 		}
 
 		//ellipsizing label for the title
@@ -314,6 +315,7 @@ public class Browser {
 
 		comments1.Active = SettingsHandler.Settings.ShowComments;
 
+		cut1.Sensitive = false;
 		paste1.Sensitive = false;
 
 		//
@@ -559,10 +561,12 @@ public class Browser {
 	
 	public void LinkClicked (object o, EventArgs args)
 	{
+		string url = CurrentTab.html.Url;
+			
 		if (HoldCtrl)
-			AddTab();
+			AddTab ();
 
-		LoadUrl (CurrentTab.html.Url);
+		LoadUrl (url);
 	}
 
 	private System.Xml.XmlNode edit_node;
@@ -826,14 +830,14 @@ ExtLoop:
 		// postcomment.Sensitive = comments1.Active;
 
 		// refresh, so we can see the comments
-		if (CurrentTab.history != null) // catch the case when we are currently loading
+		if (CurrentTab != null && CurrentTab.history != null) // catch the case when we are currently loading
 			CurrentTab.history.ActivateCurrent ();
 	}
 	
 	void OnInheritedMembersActivate (object o, EventArgs args)
 	{
 		SettingsHandler.Settings.ShowInheritedMembers = showinheritedmembers.Active;
-		if (CurrentTab.history != null) // catch the case when we are currently loading
+		if (CurrentTab != null && CurrentTab.history != null) // catch the case when we are currently loading
 			CurrentTab.history.ActivateCurrent ();
 	}
 
@@ -842,7 +846,7 @@ ExtLoop:
 		SettingsHandler.Settings.EnableEditing = editing1.Active;
 
 		// refresh, so we can see the [edit] things
-		if (CurrentTab != null) // catch the case when we are currently loading
+		if (CurrentTab != null && CurrentTab.history != null) // catch the case when we are currently loading
 			CurrentTab.history.ActivateCurrent ();
 	}
 	
@@ -873,7 +877,6 @@ ExtLoop:
 	//
 	// Invoked when the user presses a key on the index_entry
 	//
-
 	public void OnIndexEntryKeyPress (object o, KeyPressEventArgs args)
 	{
 		args.RetVal = true;
@@ -924,6 +927,17 @@ ExtLoop:
 		Application.Quit ();
 	}
 
+	//
+	// Invoked by Edit/Cut menu entry.
+	//
+	void OnCutActivate (object sender, EventArgs a)
+	{
+		if (CurrentTab.Tab_mode == Mode.Editor) {
+			Clipboard cb = Clipboard.Get (Gdk.Selection.Clipboard);
+			CurrentTab.text_editor.Buffer.CutClipboard (cb, true);
+		}
+	}
+
 	//
 	// Invoked by Edit/Copy menu entry.
 	//
@@ -947,9 +961,11 @@ ExtLoop:
 		if (!cb.WaitIsTextAvailable ())
 			return;
 
-		string text = cb.WaitForText ();
+		//string text = cb.WaitForText ();
 
-		CurrentTab.text_editor.Buffer.InsertAtCursor (text);
+		//CurrentTab.text_editor.Buffer.InsertAtCursor (text);
+
+		CurrentTab.text_editor.Buffer.PasteClipboard (cb);
 	}
 
 	class About {
@@ -968,7 +984,13 @@ ExtLoop:
 
 			about.TransientFor = parent.window1;
 
-			logo_image.Pixbuf = new Gdk.Pixbuf (null, "monodoc.png");
+			Gdk.Pixbuf icon = new Gdk.Pixbuf (null, "monodoc.png");
+
+			if (icon != null) {
+				about.Icon = icon;
+				logo_image.Pixbuf = icon;
+			}
+
 			Assembly assembly = Assembly.GetExecutingAssembly ();
 			label_version.Markup = String.Format ("<b>Version:</b> {0}", assembly.GetName ().Version.ToString ());
 		}
@@ -1368,6 +1390,112 @@ ExtLoop:
 		}
 	}
 
+	void OnContributionStatistics (object sender, EventArgs a)
+	{
+		string email = SettingsHandler.Settings.Email;
+		string key = SettingsHandler.Settings.Key;
+		
+		if (key == null || key == "") {
+			MessageDialog md = new MessageDialog (null, 
+							      DialogFlags.DestroyWithParent,
+							      MessageType.Info, 
+							      ButtonsType.Close, 
+				                  "You have not obtained or used a contribution key yet.");
+			md.Title = "No contribution key";
+			
+			md.Run();
+			md.Destroy();
+		}
+		else
+			ContributionStatus.GetStatus (email, key);
+	}
+	
+	class ContributionStatus {
+		enum State {
+			GetStatusError,
+			NetworkError,
+			Done
+		}
+
+		State state;
+		Status status;
+		string contributoremail;
+		
+		ThreadNotify tn;
+		WebClientAsyncResult war;
+		ContributionsSoap d;
+		
+		public static void GetStatus (string email, string key)
+		{
+			new ContributionStatus(email, key);
+		}
+		
+		ContributionStatus (string email, string key)
+		{
+			tn = new ThreadNotify (new ReadyEvent (Update));
+			
+			d = new ContributionsSoap ();
+			if (Environment.GetEnvironmentVariable ("MONODOCTESTING") == null)
+				d.Url = "http://www.go-mono.com/docs/server.asmx";
+				
+			war = (WebClientAsyncResult) d.BeginGetStatus (email, key, new AsyncCallback (GetStatusDone), null);
+			contributoremail = email;
+		}
+		
+		void Update ()
+		{
+			MessageDialog md = null;
+			
+			switch (state) {
+			case State.GetStatusError:
+				md = new MessageDialog (null, 
+					              DialogFlags.DestroyWithParent,
+							      MessageType.Error, ButtonsType.Close, 
+				                  "Server returned error while requesting contributor statistics");
+				md.Title = "Contribution Statistics Error Occurred";
+				break;
+			case State.NetworkError:
+				md = new MessageDialog (null, 
+					              DialogFlags.DestroyWithParent,
+							      MessageType.Error, ButtonsType.Close, 
+				                  "Network error occurred while requesting contributor statistics");
+				md.Title = "Contribution Statistics Error Occurred";
+				break;
+			case State.Done:
+				md = new MessageDialog (null, 
+					              DialogFlags.DestroyWithParent,
+							      MessageType.Info, ButtonsType.Close, 
+				                  "Contribution statistics for " + contributoremail +
+					              "\n\nTotal contributions: " + status.Contributions +
+					              "\nContributions committed: " + status.Commited +
+					              "\nContributions pending: " + status.Pending);
+				md.Title = "Contribution Statistics";
+				break;
+			}
+
+			md.Run();
+			md.Destroy();
+		}
+				
+		void GetStatusDone (IAsyncResult iar)
+		{
+			try {
+				status = d.EndGetStatus (iar);
+				war = null;
+
+				if (status == null)
+					state = State.GetStatusError;
+				else
+					state = State.Done;
+
+			} catch (Exception e) {
+				state = State.NetworkError;
+				Console.WriteLine ("Error getting status: " + e);
+			}
+			if (tn != null)
+				tn.WakeupMain ();
+		}	
+	}
 
 	class NewComment {
 		[Glade.Widget] Window newcomment;
@@ -2287,11 +2415,13 @@ public class Tab : Notebook {
 		
 		if (m == Mode.Viewer) {
 			this.Page = 0;
+			browser.cut1.Sensitive = false;
 			browser.paste1.Sensitive = false;
 			browser.print.Sensitive = true;
 			EditImg.Visible = false;
 		} else {
 			this.Page = 1;
+			browser.cut1.Sensitive = true;
 			browser.paste1.Sensitive = true;
 			browser.print.Sensitive = false;
 			EditImg.Visible = true;
